aboutsummaryrefslogtreecommitdiff
path: root/openssl/update-snapshot.sh
diff options
context:
space:
mode:
Diffstat (limited to 'openssl/update-snapshot.sh')
-rwxr-xr-xopenssl/update-snapshot.sh9
1 files changed, 5 insertions, 4 deletions
diff --git a/openssl/update-snapshot.sh b/openssl/update-snapshot.sh
index d85d9a3c..0ebc31db 100755
--- a/openssl/update-snapshot.sh
+++ b/openssl/update-snapshot.sh
@@ -2,11 +2,11 @@
# $Id$
#
# Fetch today's OpenSSL tarball and do everything needed to make it
# the current code other than the svn commit.
#version="1.0.0-stable-SNAP-$(date +%Y%m%d)"
-version="1.0.2h"
+version="1.0.2j"
tarball="openssl-${version}.tar.gz"
@@ -24,11 +24,12 @@ do
if [ "$i" != "$tarball" ]
then
/bin/rm -rf "${i%.tar.gz}"
- /usr/local/bin/svn rm "$i"
+ /usr/local/bin/git rm "$i"
fi
done
/usr/bin/awk -v version="$version" '/^VERSION = / {$NF = version} {print}' Makefile.in >Makefile.in.$$ &&
/bin/mv Makefile.in.$$ Makefile.in
-/usr/local/bin/svn add "$tarball"
+/usr/local/bin/git add -v "$tarball"
+/usr/local/bin/git add -v -u
@@ -2,11 +2,11 @@
#
# Fetch today's OpenSSL tarball and do everything needed to make it
-# the current code other than the svn commit.
+# the current code other than the git commit.
#version="1.0.0-stable-SNAP-$(date +%Y%m%d)"